Players rates — SoL 3 user manual

### Navigation

- index
- next |
- previous |
- User manual »
- User interface »
- Basic entities »

# Players rates

Each rating produces a series of rates for each player, one for each tourney associated with that rating he partecipates to. The most recent rate of each player compose a ranking that weight the mutual strength, even when the players did not meet each other directly.

This ranking allows the generation of non-random couplings in the subsequent tourneys. As a statistical byproduct it is possible to obtain the trend in time of the strength of the players, as a graphical chart.

## Menu actions

Chart
  Shows a graphical chart of the historic trend of the rates of the selected players
Print
  Generate a PDF document with the ranking of the players rates

### Navigation

- index
- next |
- previous |
- User manual »
- User interface »
- Basic entities »